# Project Description

**A python package for solving 1D kinematics problems.**

## Installation

```
pip3 install kinematics5
```

## Inspiration

As a high school AP physics tutor, I wanted to make a python package for solving kinematics problems.

## Examples

## License

Distributed under the terms of the MIT license, ```kinematics5``` is free and open source software.